<!-- This page is formatted for GitHub's markdown renderer -->
![AIQC (wide)](https://raw.githubusercontent.com/aiqc/aiqc/main/docs/images/aiqc_logo_banner_controlroom.png)

<br />

<h3 align='center'>📚&nbsp;&nbsp;<a href="https://aiqc.readthedocs.io/">Documentation</a></h3>

<h3 align='center'>🛡️&nbsp;&nbsp;<a href="https://aiqc.readthedocs.io/en/latest/community.html">Community</a></h3>

<br />

---

<br />

<p align='center'><b>AIQC is a Python framework for rapid, rigorous, & reproducible deep learning.</b></p>

<br />

![Framework](https://raw.githubusercontent.com/aiqc/aiqc/main/docs/images/framework_may12.png)

<br />

<p align='center'><b>On a mission to accelerate open science:</b></p>

* Write 95% less code. Easily integrate best practice deep learning into your research.
* Reproducibly record your entire workflow: both training experiments & preprocessing.
* Free tools & open methods, not walled garden SaaS apps & cloud services.